"""
PyGL3Display
(C) David Griffin (2010-present)
"Habilain" is a pseudonym used by David Griffin in a number of places.

A high performance Pygame OpenGL library, capable of handling 1000s of sprites

Requirements: Python, Pygame, PyOpenGL, Open GL 2.0 graphics hardware

Licensed under GPLv2 or GPLv3. You should have received a copy of both of these
licenses in the files GPLv2.txt and GPLv3.txt. If not these licenses can be
found at http://www.gnu.org/licenses/gpl-2.0.html (GPLv2) and
http://www.gnu.org/licenses/gpl-3.0.html (GPLv3). By using this file you agree
to be bound by at least one of these licenses.

Other licenses, including commercial/proprietary licenses, can be arranged by 
contacting me via e-mail at habilain@gmail.com. If you do not have in physical 
writing an alternative license agreement from me, you must use one of the 
licenses specified above when releasing work which makes use of this library.

pygl3display.examples.rendertotexture

Provides an example of render to texture support.
"""

from exampleskeleton import *
import png
import struct
import math
import objgraph
from array import array
from pygl3display.twodtextureconverter import Converter
from pygl3display.twodtexture import TwoDTexture
  
class TestApp(ExampleSkeleton):
    def __init__(self):
        """Initialise the test app data"""
        super(TestApp, self).__init__('RenderToTexture', (70, 70))
        self.count = 0
        self.total = 0
        
    def init(self):
        """Initialise the example; all the showcase items here are being 
        rendered onto a texture target"""
        self.target = TwoDTextureTarget(128)
        red = (255, 0, 0, 255)
        green = (0, 255, 0, 255)
        blue = (0, 0, 255, 255)
        square = [(-10, 10), (10, 10), (10, -10), (-10, -10)]
        tri = [(-10, 10), (10, 10), (10, -10)]
        self.ellipse = Ellipse(dx=5, dy=15, pos=(50, 20), 
                               rotation = math.pi/4, color=green, 
                               target = self.target)
        self.lines = Lines(vertices=[(10, 10), (10, 30), (30, 30), (30, 10)],
                           target = self.target)
        SpriteCommon.setDefaultFilter('nearest')
        self.block = loadImage('data/baseblock.png', wrapped=True)
        self.sprite = Sprite(image=self.block, position=(10, 35), tiling=(3,3),
                             target = self.target)
        self.tri1 = Triangles(vertices=tri, pos=(50, 50), color=red, 
                              target = self.target)
        

    def loop(self, dt):
        """Render the texture target, then make a sprite based on it that will
        be drawn to the main screen"""
        self.count += dt
        GLCommon.doTasks(self.target)
        self.spriteImage = Converter.textureAsSprite(self.target.texture)
        

if __name__ == '__main__':
    x = TestApp()
    x.run()
