"""
PyGL3Display
(C) David Griffin (2010-present)
"Habilain" is a pseudonym used by David Griffin in a number of places.

A high performance Pygame OpenGL library, capable of handling 1000s of sprites

Requirements: Python, Pygame, PyOpenGL, Open GL 2.0 graphics hardware

Licensed under GPLv2 or GPLv3. You should have received a copy of both of these
licenses in the files GPLv2.txt and GPLv3.txt. If not these licenses can be
found at http://www.gnu.org/licenses/gpl-2.0.html (GPLv2) and
http://www.gnu.org/licenses/gpl-3.0.html (GPLv3). By using this file you agree
to be bound by at least one of these licenses.

Other licenses, including commercial/proprietary licenses, can be arranged by 
contacting me via e-mail at habilain@gmail.com. If you do not have in physical 
writing an alternative license agreement from me, you must use one of the 
licenses specified above when releasing work which makes use of this library.

pygl3display.gl.cffigl.cffigl_dev4

Python port of http://www.opengl-tutorial.org/ Example 4"""

from cffigl import *
from cffigl_dev_share import *
import math

vertexShader = """
#version 120

// Input vertex data, different for all executions of this shader.
attribute vec3 vertexPosition_modelspace;
attribute vec3 vertexColor;

// Output data ; will be interpolated for each fragment.
varying vec3 fragmentColor;
// Values that stay constant for the whole mesh.
uniform mat4 MVP;

void main(){    

    // Output position of the vertex, in clip space : MVP * position
    gl_Position =  MVP * vec4(vertexPosition_modelspace,1);

    // The color of each vertex will be interpolated
    // to produce the color of each fragment
    fragmentColor = vertexColor;
}
"""

fragmentShader = """
#version 120

// Interpolated values from the vertex shaders
varying vec3 fragmentColor;

void main(){

    // Output color = color specified in the vertex shader, 
    // interpolated between all 3 surrounding vertices
    gl_FragColor = vec4(fragmentColor, 1);

}
"""

vdata = [-1.0,-1.0, -1.0, -1.0,-1.0, 1.0, -1.0, 1.0, 1.0,
    1.0, 1.0,-1.0, -1.0,-1.0,-1.0, -1.0, 1.0,-1.0,
    1.0,-1.0, 1.0, -1.0,-1.0,-1.0, 1.0,-1.0,-1.0,
    1.0, 1.0,-1.0, 1.0,-1.0,-1.0, -1.0,-1.0,-1.0,
    -1.0,-1.0,-1.0, -1.0, 1.0, 1.0, -1.0, 1.0,-1.0,
    1.0,-1.0, 1.0, -1.0,-1.0, 1.0, -1.0,-1.0,-1.0,
    -1.0, 1.0, 1.0, -1.0,-1.0, 1.0, 1.0,-1.0, 1.0,
    1.0, 1.0, 1.0, 1.0,-1.0,-1.0, 1.0, 1.0,-1.0,
    1.0,-1.0,-1.0, 1.0, 1.0, 1.0, 1.0,-1.0, 1.0,
    1.0, 1.0, 1.0, 1.0, 1.0,-1.0, -1.0, 1.0,-1.0,
    1.0, 1.0, 1.0, -1.0, 1.0,-1.0, -1.0, 1.0, 1.0,
    1.0, 1.0, 1.0, -1.0, 1.0, 1.0, 1.0,-1.0, 1.0]
cdata=[0.583, 0.771, 0.014, 0.609, 0.115, 0.436, 
0.327, 0.483, 0.844, 0.822, 0.569, 0.201, 
0.435, 0.602, 0.223, 0.310, 0.747, 0.185, 
0.597, 0.770, 0.761, 0.559, 0.436, 0.730, 
0.359, 0.583, 0.152, 0.483, 0.596, 0.789, 
0.559, 0.861, 0.639, 0.195, 0.548, 0.859, 
0.014, 0.184, 0.576, 0.771, 0.328, 0.970, 
0.406, 0.615, 0.116, 0.676, 0.977, 0.133, 
0.971, 0.572, 0.833, 0.140, 0.616, 0.489, 
0.997, 0.513, 0.064, 0.945, 0.719, 0.592, 
0.543, 0.021, 0.978, 0.279, 0.317, 0.505, 
0.167, 0.620, 0.077, 0.347, 0.857, 0.137, 
0.055, 0.953, 0.042, 0.714, 0.505, 0.345, 
0.783, 0.290, 0.734, 0.722, 0.645, 0.174, 
0.302, 0.455, 0.848, 0.225, 0.587, 0.040, 
0.517, 0.713, 0.338, 0.053, 0.959, 0.120, 
0.393, 0.621, 0.362, 0.673, 0.211, 0.457, 
0.820, 0.883, 0.371, 0.982, 0.099, 0.879]
gl = GL()
makeWindow(gl, (800, 600), "Test Title")
gl.glfwEnable(gl.GLFW_STICKY_KEYS)
vertexArrayID = gl.glGenVertexArrays()
gl.glBindVertexArray(vertexArrayID)
gl.glClearColor(0.0, 0.0, 0.3, 1.0)
gl.glEnable(gl.GL_DEPTH_TEST)
gl.glDepthFunc(gl.GL_LESS) 
programID = LoadShaders(gl, vertexShader, fragmentShader)
vertexPosition_modelspace_loc = gl.glGetAttribLocation(programID, 'vertexPosition_modelspace')
matrixID = gl.glGetUniformLocation(programID, "MVP")
vertexColorID = gl.glGetAttribLocation(programID, "vertexColor")
data = gl.new('GLfloat[]', vdata)
vertexbuffer =  gl.glGenBuffers()
gl.glBindBuffer(gl.GL_ARRAY_BUFFER, vertexbuffer)
gl.glBufferData(gl.GL_ARRAY_BUFFER, gl.sizeof(data), 
                data, gl.GL_STATIC_DRAW)
colorBuffer = gl.glGenBuffers()
gl.glBindBuffer(gl.GL_ARRAY_BUFFER, colorBuffer)
data2 = gl.new('GLfloat[]', cdata)
gl.glBufferDataf(gl.GL_ARRAY_BUFFER, cdata, gl.GL_STATIC_DRAW)
projectionMatrix = perspective(math.pi/4.0, 4.0 / 3.0, 0.1, 100.0)
viewMatrix = lookat(vec3(4,3,3), vec3(0,0,0), vec3(0,1,0))                      
mvp = viewMatrix * projectionMatrix

while (gl.glfwGetKey(gl.GLFW_KEY_ESC) != gl.GLFW_PRESS and 
                    gl.glfwGetWindowParam(gl.GLFW_OPENED)):
    gl.glClear(gl.GL_COLOR_BUFFER_BIT | gl.GL_DEPTH_BUFFER_BIT)
    gl.glUseProgram(programID)
    gl.glUniformMatrix4fv(matrixID, 1, gl.GL_FALSE, mvp.data());
    gl.glEnableVertexAttribArray(0);
    gl.glBindBuffer(gl.GL_ARRAY_BUFFER, vertexbuffer);
    gl.glVertexAttribPointer(vertexPosition_modelspace_loc, 3, gl.GL_FLOAT, 
                                 gl.GL_FALSE, 0, gl.offsetPointer(0))
    gl.glEnableVertexAttribArray(1);
    gl.glBindBuffer(gl.GL_ARRAY_BUFFER, colorBuffer);
    gl.glVertexAttribPointer(vertexColorID, 3, gl.GL_FLOAT, 
                             gl.GL_FALSE, 0, gl.offsetPointer(0));
    gl.glDrawArrays(gl.GL_TRIANGLES, 0, 3*12);
    gl.glDisableVertexAttribArray(0);
    gl.glDisableVertexAttribArray(1);
    gl.glfwSwapBuffers()
gl.glfwTerminate()
