"""
PyGL3Display
(C) David Griffin (2010-present)
"Habilain" is a pseudonym used by David Griffin in a number of places.

A high performance Pygame OpenGL library, capable of handling 1000s of sprites

Requirements: Python, Pygame, PyOpenGL, Open GL 2.0 graphics hardware

Licensed under GPLv2 or GPLv3. You should have received a copy of both of these
licenses in the files GPLv2.txt and GPLv3.txt. If not these licenses can be
found at http://www.gnu.org/licenses/gpl-2.0.html (GPLv2) and
http://www.gnu.org/licenses/gpl-3.0.html (GPLv3). By using this file you agree
to be bound by at least one of these licenses.

Other licenses, including commercial/proprietary licenses, can be arranged by 
contacting me via e-mail at habilain@gmail.com. If you do not have in physical 
writing an alternative license agreement from me, you must use one of the 
licenses specified above when releasing work which makes use of this library.

pygl3display.gl.pygl3display

Provides the GL Binding of PyGL3Display. This can either be OpenGL or CFFI
implementation"""

import OpenGL
OpenGL.FORWARD_COMPATIBLE_ONLY = True
OpenGL.UNSIGNED_BYTE_IMAGES_AS_STRING = True
del OpenGL

from OpenGL.GL import *
import OpenGL.GL
FBOENABLED = True
try:
    from OpenGL.GL import (glGenFramebuffers, glFramebufferTexture2D, 
    glCheckFramebufferStatus, glBindFramebuffer, 
    GL_FRAMEBUFFER, GL_FRAMEBUFFER_COMPLETE,)
    import OpenGL.GL as _FBOLib
except ImportError:
    try:
        from OpenGL.GL.EXT.framebuffer_object import (
            glGenFramebuffersEXT as glGenFramebuffers, 
            glBindFramebufferEXT as glBindFramebuffer,
            glFramebufferTexture2DEXT as glFramebufferTexture2D,
            glCheckFramebufferStatusEXT as glCheckFramebufferStatus,
            GL_FRAMEBUFFER_EXT as GL_FRAMEBUFFER,
            GL_FRAMEBUFFER_COMPLETE_EXT as GL_FRAMEBUFFER_COMPLETE,
            GL_MAX_COLOR_ATTACHMENTS_EXT as GL_MAX_COLOR_ATTACHMENTS)
        import OpenGL.GL.EXT.framebuffer_object as _FBOLib
    except ImportError:
        FBOENABLED = False
        
def importFBOName(name):
    """Imports from the Framebuffer object library, taking into account
    that there may be an 'EXT' or '_EXT' appended."""
    names = [name, name + 'EXT', name + '_EXT']
    lookup = _FBOLib.__dict__
    for name in names:
        if name in lookup:
            return lookup[name]
    raise ImportError('FBO Bindings have no %s' % name)

# These are compatibility hacks - they are not complete by any means, nor
# do they always give expected behaviour.        
glGetShaderi = glGetShaderiv
glGetProgrami = glGetProgramiv
glGenTexture = lambda: OpenGL.GL.glGenTextures(1)
glDeleteTexture = glDeleteTextures
glGetTexLevelParameteri = glGetTexLevelParameteriv
glGenFramebuffer = lambda: glGenFramebuffers(1)
glGenTextures = lambda x: [OpenGL.GL.glGenTextures(1)] if x == 1 else OpenGL.GL.glGenTextures