"""
PyGL3Display
(C) David Griffin (2010-present)
"Habilain" is a pseudonym used by David Griffin in a number of places.

A high performance Pygame OpenGL library, capable of handling 1000s of sprites

Requirements: Python, Pygame, PyOpenGL, Open GL 2.0 graphics hardware

Licensed under GPLv2 or GPLv3. You should have received a copy of both of these
licenses in the files GPLv2.txt and GPLv3.txt. If not these licenses can be
found at http://www.gnu.org/licenses/gpl-2.0.html (GPLv2) and
http://www.gnu.org/licenses/gpl-3.0.html (GPLv3). By using this file you agree
to be bound by at least one of these licenses.

Other licenses, including commercial/proprietary licenses, can be arranged by 
contacting me via e-mail at habilain@gmail.com. If you do not have in 
writing an alternative license agreement from me, you must use one of the 
licenses specified above when releasing work which makes use of this library.

pygl3display.glcommon.glfwcommon

A GLCommon instance that uses glfw. Requires cffigl - .
"""

from pygl3display.initialise import Initialiser
from pygl3display.glcommon.base import GLCommonClass
from pygl3display.gl.cffigl import *

class GLCommonGLFW(GLCommonClass):
    def init(self):
        if not glfwInit():
            raise Exception('GLFW Initialisation failed')
        
    def createContext(self, resolution, doublebuffer, fullscreen):
        if not glfwInit():
            raise Exception('GLFW Initialisation failed')
        glfwOpenWindowHint(GLFW_FSAA_SAMPLES, 4)
        glfwOpenWindowHint(GLFW_OPENGL_VERSION_MAJOR, 2)
        glfwOpenWindowHint(GLFW_OPENGL_VERSION_MINOR, 1)
        mode = GLFW_WINDOW if not fullscreen else GLFW_FULLSCREEN
    
        if not glfwOpenWindow(resolution[0], resolution[1], 0,0,0,0, 32,0, mode):
            glfwTerminate()
            raise Exception('Could not open GLFW Window')
        resyncInterval = 1 if doublebuffer else 0
        glfwSwapInterval(resyncInterval)
        Initialiser.initialise()
        
    redraw = staticmethod(glfwSwapBuffers)
        

