"""
PyGL3Display
(C) David Griffin (2010-present)
"Habilain" is a pseudonym used by David Griffin in a number of places.

A high performance Pygame OpenGL library, capable of handling 1000s of sprites

Requirements: Python, Pygame, PyOpenGL, Open GL 2.0 graphics hardware

Licensed under GPLv2 or GPLv3. You should have received a copy of both of these
licenses in the files GPLv2.txt and GPLv3.txt. If not these licenses can be
found at http://www.gnu.org/licenses/gpl-2.0.html (GPLv2) and
http://www.gnu.org/licenses/gpl-3.0.html (GPLv3). By using this file you agree
to be bound by at least one of these licenses.

Other licenses, including commercial/proprietary licenses, can be arranged by 
contacting me via e-mail at habilain@gmail.com. If you do not have in 
writing an alternative license agreement from me, you must use one of the 
licenses specified above when releasing work which makes use of this library.

pygl3display.tests.spritememleak

Test used to debug memory leak in sprites (and potentially other things)
"""

try:
    import pygl3display
except ImportError:
    import sys, os.path
    sys.path.append(os.path.join('..', '..'))
    import pygl3display

from pygl3display import *
from pygl3display.examples.exampleskeleton import *
from weakref import ref
import gc
import objgraph

class SpriteMemLeakTest(ExampleSkeleton):
    def __init__(self):
        self.size = (400, 400)
        super(SpriteMemLeakTest, self).__init__('SpriteMemLeakTest', self.size)
        
    def init(self):
        self.image = loadImage(os.path.join('..', 'examples', 'data', 'ball.png'))
        self.sprite = Sprite(image=self.image, position=(50, 50))
        self.renderref = ref(self.sprite._renderer)
        del self.sprite 
        del self.image
        gc.collect() # Expect renderref to be dead by now
        objgraph.show_refs([self.renderref()], filename='fwdrefs.png')
        objgraph.show_backrefs([self.renderref()], filename='bckrefs.png')
        
if __name__ == '__main__':
    x = SpriteMemLeakTest()
    x.run()
    
    
        

